function struc = INP_FUNC_esurf(struc,sname)
% format data and specify priors

% Designed for our pre-existing NCL datasets. 
% Alter this file as needed

struc2=[];
struc2.SampleName=sname;

% Multigrain sensitivity data. This involves sens: a list of the MG
% sensitivity per gray (for all aliquots, including rejected), and a
% corresponding list of aliquot sizes.
% put these in fields called .sens and .sens_isize

% this section formats the NCL data as such, ---------------------------

struc2.sens=struc.sens;
if length(struc.sens_isize(:,1))==1
    struc2.sens_isize=ones(length(struc.sens),1)*struc.sens_isize;
else
    struc2.sens_isize=[];
    for i=1:length(struc.sens_isize(:,1))
        t1=ones(struc.sens_isize(i,2),1)*struc.sens_isize(i,1);
        struc2.sens_isize=[struc2.sens_isize; t1];
    end
end
struc2.sens_isize(:,2)=1; %one aliquot at value

% read data data and ngrains list
struc2.de=struc.de;
struc2.de(:,2)=abs(struc2.de(:,2));

if length(struc.de_isize(:,1))==1
    struc2.de_isize=ones(length(struc.de),1)*struc.de_isize;
else
    struc2.de_isize=[];
    for i=1:length(struc.de_isize(:,1))
        t1=ones(struc.de_isize(i,2),1)*struc.de_isize(i,1);
        struc2.de_isize=[struc2.de_isize; t1];
    end
end
struc2.de_isize(:,2)=1; %one aliquot at value
%-----------------------------------------------------------------------


% Set tolerances for MCMC main-phase convergence ======================
% Defined in the Gelman book. As the markov chains converge, the
% convergence measure falls towards 1. Set the convergence on all
% parameters to 1.1, or perhaps 1.05 for the parameter of interest. 
% The tolerance can be reduced for testing.

% parameters in order [gamma sigma p a b]
struc2.tolerance=[1.1 1.1 1.1 1.1 1.1];
%struc2.tolerance=[2 2 2 2 2]; %e.g. for testing


% Specify whether MAM3 or MAM3ul will be used for the bootstrap
% likelihoods.
t1=min(struc2.de(:,1));
if t1>0
    struc2.mamflag=1; %1 for mam3, 2 for mam3ul
else
    struc2.mamflag=2;

end

%----- DELETE EXTREME HIGH OUTLIERS - NOT SUITED TO HALF-NORMAL SD2-----
highcut=20;
t1=max(struc2.de(:,1));
if t1>highcut
    ind=struc2.de(:,1)<highcut;
    struc2.de=struc2.de(ind,:);
    struc2.de_isize=struc2.de_isize(ind,:);
end


% Specify Priors ========================================================
% by calling a particular function file. change or amend these as needed.

struc2.prior.burial = Pr_burial_Uniform(0.01,3); % (min,max)

struc2.prior.sd2 = Pr_sd2_esurf(100);

struc2.prior.p = Pr_p_esurf(100);

struc2.prior.A=Pr_A_esurf(30);

struc2.prior.B=Pr_B_esurf(30);

% The expected overdispersion in the burial dose ========================
struc2.IPARAM.SGsigb=0.20; % scatter in the SG Burial dose (fixed)
struc2.IPARAM.sigb=[0.12 0.02]; % sigma_b used for the MAM3 and MAM3ul.% THE ERROR TERM IS NOT USED HERE


%Define the Measeurement conditions ====================================
% the model involves repeated simulation of a single-regen dose response curve
% this file contains the dose points used. Can be altered, but probably not
% necessary unless changing the shape of the curve.
load MeasCond_4110
struc2.DR=DR;
struc2.CRIT=CRIT;

%finish by assigning struc:
struc=struc2;

