function struc = findgamma_NGRAINS(struc,sens,isize)
% estimate SG sensitivity parameters from MG sensitivity measurements

N_markov=3; % number of markov chains
burnin=0.5; % proportion of iterations discarded
tolerance=1.03; % convergence
min_i=2000; % min iterations


%gamma fit the MG sens distribution using matlab functions
aliquot=ceil(sens); % can't have zeros!!!- will give NaN in sd_phat
ind=aliquot<1; aliquot(ind)=1;
[size.phat size.pci] = gamfit(aliquot,0.318); %alpha of 31.8 should reurn 1 sigma confidence region
sd_phat=mean(abs(size.phat(1)-size.pci(1:2,1))); %assume normal likelihood
sd_bval=mean(abs(size.phat(2)-size.pci(1:2,2))); %assume normal likelihood

%draw from starting distribution, ensuring non-zero posterior densities

MARK=[];
for h=1:N_markov
    MARK(h).Olist=zeros(1,3);
    while MARK(h).Olist(1,3)==0   
        
        ai=randsample(struc.prior.A(:,1),1,true,struc.prior.A(:,2));
        bi=abs(randn*sd_bval+size.phat(2)); % SG value should be the same as MG value
        
        aliquot2=[];
        
        %simultate MG aliquot:
            na=length(sens);
            for j=1:na
                %R = gamrnd(ai,bi,isize,1);
                R = gamrnd(ai,bi,isize(j),1);
                aliquot2(j)=poissrnd(sum(R));
            end
            aliquot2=ceil(aliquot2);
            ind=aliquot2<1;
            aliquot2(ind)=1;
        
        %estimate params:
        [phat2] = gamfit(aliquot2);

        %density
        dens1=normpdf(phat2(1),size.phat(1),sd_phat);
        dens2=normpdf(phat2(2),size.phat(2),sd_bval);
        
        %showme = [ai bi]
        priors(1)=evalprior(struc.prior.A,ai);
        priors(2)=evalprior(struc.prior.B,bi);
        
        postdens=dens1*dens2*prod(priors);
        MARK(h).Olist(1,1:3)=[log(ai) log(bi) postdens];
        %save MARK MARK
    end
end


k=0;
kk=0;
Rhat=[];
i=1;
flag=10;
while or(flag>tolerance,i<min_i)
    i=i+1;
    for h=1:N_markov
        %propose new theta from jumping distr.
        theta=MARK(h).Olist(i-1,1:2);
        densTheta=MARK(h).Olist(i-1,3);
        ThetaStar(1)=randn*0.1+theta(1);
        ThetaStar(2)=randn*0.1+theta(2);
        ThetaStar=exp(ThetaStar);
        
        aliquot2=[];
        %simultate MG aliquot:
  
        na=length(sens);
        for j=1:na
            R = gamrnd(ThetaStar(1),ThetaStar(2),isize(j),1);
            aliquot2(j)=poissrnd(sum(R));
            
        end
        
        aliquto2=ceil(aliquot2);
        ind=aliquot2<1;
        aliquot2(ind)=1;
        
        %estimate params:
        phat2 = gamfit(aliquot2);
       

        %density
        dens1=normpdf(phat2(1),size.phat(1),sd_phat);
        dens2=normpdf(phat2(2),size.phat(2),sd_bval);
        %showme_thetaStar = ThetaStar
        priors(1)=evalprior(struc.prior.A,ThetaStar(1));
        priors(2)=evalprior(struc.prior.B,ThetaStar(2));
        
        densThetaStar=dens1*dens2*prod(priors);
        
        r=densThetaStar/densTheta;
            R2=rand;
            if R2<min(r,1)
                ThetaStar=log(ThetaStar);
                theta=ThetaStar;
                densTheta=densThetaStar;
                acc=1;
            else
                acc=0;
            end
        MARK(h).Olist(i,1:4)=[theta densTheta acc];
    end
    
    k=k+1;
    if k==100
        k=0;
        kk=kk+1;
        Omonster=[];
        acclist=[];
        for h=1:N_markov
            templist=MARK(h).Olist(ceil(i*burnin):i,:);
            Omonster(:,:,h)=templist(:,1:2);
            acclist(:,h)=MARK(h).Olist(ceil(i*burnin):i,4);
        end
        vbar=mean(Omonster); %size(1,3,w), called vbardotj in Gelman p296
        vbardotdot=mean(vbar,3); %size(1,3,1)
        u=length(Omonster(:,1,1)); %n in Gelman p296
        w=N_markov;         %m in Gelman p296
        s2=(1/(u-1))*sum((Omonster-repmat(vbar,u,1)).^2);
        W=mean(s2,3);
        B=(u/(w-1))*sum((vbar-repmat(vbardotdot,[1 1 w])).^2,3);
        varhatplus=((u-1)/u)*W+B/u;
        Rhat(kk,:)=sqrt(varhatplus./W)
        flag=max(Rhat(kk,1:2));
        %i;
        acc_ratio=mean(mean(acclist));
        %save MARK MARK
    end
end

Nlist=[];
for h=1:N_markov
    templist=MARK(h).Olist(ceil(i*burnin):i,:);
    Nlist=[Nlist; templist];
end
Nlist(:,1:2)=exp(Nlist(:,1:2));


% Clean up the posteriors to prevent the next MCMC getting stuck =========
%struc.prior.A = fit_lognorm(Nlist(:,1));
struc.prior.A = smooth_n_chop(Nlist(:,1));
%struc.prior.B = fit_lognorm(Nlist(:,2));
struc.prior.B = smooth_n_chop(Nlist(:,2));
struc.Glist=Nlist;


    